@@ -1,6 +1,8 @@
 """Provide some utilities"""
 import logging
 import textwrap
+from itertools import groupby
+from operator import itemgetter
 from io import StringIO
 from os import PathLike, get_terminal_size
 from collections import defaultdict
@@ -51,7 +53,7 @@ from .pluginmgr import plugin
 from .version import __version__
 
 if TYPE_CHECKING:  # pragma: no cover
-    from rich.console import RenderableType, ConsoleRenderable
+    from rich.console import RenderableType
 
 
 class RichHandler(_RichHandler):
@@ -338,8 +340,8 @@ def brief_list(blist: List[int]) -> str:
         The string to show for the briefed list.
     """
     ret = []
-    for group in consecutive_groups(blist):
-        list_group = list(group)
+    for _, g in groupby(enumerate(blist), lambda x: x[0] - x[1]):
+        list_group = list(map(itemgetter(1), g))
         if len(list_group) > 1:
             ret.append(f"{list_group[0]}-{list_group[-1]}")
         else:
@@ -362,10 +364,10 @@ def pipen_banner() -> "RenderableType":
         caption=f"version: {__version__}",
     )
     table.add_column(justify="center")
-    table.add_row(r"  _____________________________________   __")
-    table.add_row(r"  ___  __ \___  _/__  __ \__  ____/__  | / /")
-    table.add_row(r" __  /_/ /__  / __  /_/ /_  __/  __   |/ / ")
-    table.add_row(r"_  ____/__/ /  _  ____/_  /___  _  /|  /  ")
+    table.add_row(r"   _____________________________________   __")
+    table.add_row(r"   ___  __ \___  _/__  __ \__  ____/__  | / /")
+    table.add_row(r"  __  /_/ /__  / __  /_/ /_  __/  __   |/ / ")
+    table.add_row(r" _  ____/__/ /  _  ____/_  /___  _  /|  /  ")
     table.add_row(r"/_/     /___/  /_/     /_____/  /_/ |_/   ")
     table.add_row("")
 
